==> open-xchange-core_7.6.2.orig.tar.bz2: open-xchange-core-7.6.2/com.openexchange.documentation/src/com/openexchange/documentation/annotations/Type.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.documentation.annotations;

/**
 * {@link Type} - Types for {@link Parameter}s used by {@link Action}s and {@link Attribute}s used by {@link Container}s.
 *
 * @author <a href="tobias.friedrich@open-xchange.com">Tobias Friedrich</a>
 */
public enum Type {
	/**
	 * Value   ::= "null" | Boolean | Number | String | Array | Object
	 */
	VALUE,
	/**
	 * Boolean ::= "true" | "false"
	 */
	BOOLEAN,
	/**
	 * Number  ::= see NumericLiteral in ECMA 262 3rd edition
	 */
	NUMBER,
	/**
	 * String  ::= \"([^"\n\\]|\\["\n\\])*\"
	 */
	STRING,
	/**
	 * Array   ::= "[]" | "[" Value ("," Value)* "]"
	 */
	ARRAY,
	/**
	 * Object  ::= "{}" | "{" Name ":" Value ("," Name ":" Value)* "}"
	 */
	OBJECT,
	/**
	 * Name    ::= [A-Fa-f][0-9A-Fa-f_]*
	 */
	NAME,
}

==> open-xchange-core_7.8.4.orig.tar.bz2: open-xchange-core-7.8.4/com.openexchange.documentation/src/com/openexchange/documentation/annotations/Type.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.documentation.annotations;

/**
 * {@link Type} - Types for {@link Parameter}s used by {@link Action}s and {@link Attribute}s used by {@link Container}s.
 *
 * @author <a href="tobias.friedrich@open-xchange.com">Tobias Friedrich</a>
 * @deprecated Never used & obsolete, therefore <b>to be removed with v7.10.0</b>. See <a href="../../../../../http-api/readme.md">http-api/readme.md</a> for details about API documentation.
 */
@Deprecated
public enum Type {
	/**
	 * Value   ::= "null" | Boolean | Number | String | Array | Object
	 */
	VALUE,
	/**
	 * Boolean ::= "true" | "false"
	 */
	BOOLEAN,
	/**
	 * Number  ::= see NumericLiteral in ECMA 262 3rd edition
	 */
	NUMBER,
	/**
	 * String  ::= \"([^"\n\\]|\\["\n\\])*\"
	 */
	STRING,
	/**
	 * Array   ::= "[]" | "[" Value ("," Value)* "]"
	 */
	ARRAY,
	/**
	 * Object  ::= "{}" | "{" Name ":" Value ("," Name ":" Value)* "}"
	 */
	OBJECT,
	/**
	 * Name    ::= [A-Fa-f][0-9A-Fa-f_]*
	 */
	NAME,
}
